@@ -126,27 +126,17 @@ def get_observer_look(sat_lon, sat_lat, sat_alt, utc_time, lon, lat, alt):
     top_z = cos_lat * cos_theta * rx + \
         cos_lat * sin_theta * ry + sin_lat * rz
 
-    az_ = np.arctan(-top_e / top_s)
-
-    if has_xarray and isinstance(az_, xr.DataArray):
-        az_data = az_.data
-    else:
-        az_data = az_
-
-    if has_dask and isinstance(az_data, da.Array):
-        az_data = da.where(top_s > 0, az_data + np.pi, az_data)
-        az_data = da.where(az_data < 0, az_data + 2 * np.pi, az_data)
-    else:
-        az_data[np.where(top_s > 0)] += np.pi
-        az_data[np.where(az_data < 0)] += 2 * np.pi
-
-    if has_xarray and isinstance(az_, xr.DataArray):
-        az_.data = az_data
-    else:
-        az_ = az_data
+    # Azimuth is undefined when elevation is 90 degrees, 180 (pi) will be returned.
+    az_ = np.arctan2(-top_e, top_s) + np.pi
+    az_ = np.mod(az_, 2 * np.pi)  # Needed on some platforms
 
     rg_ = np.sqrt(rx * rx + ry * ry + rz * rz)
-    el_ = np.arcsin(top_z / rg_)
+
+    top_z_divided_by_rg_ = top_z / rg_
+
+    # Due to rounding top_z can be larger than rg_ (when el_ ~ 90).
+    top_z_divided_by_rg_ = top_z_divided_by_rg_.clip(max=1)
+    el_ = np.arcsin(top_z_divided_by_rg_)
 
     return np.rad2deg(az_), np.rad2deg(el_)
 
